# Model

This directory contains some models for testing sampling algorithms.
The Gaussian class is used to construct multivariate Gaussians.
It is mainly used for demonstration purposes, to show the required interface for adapters to third party simulators.